<?php

namespace Drupal\jsonapi_links;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\jsonapi_links\Form\SettingsForm;

/**
 * The helper service to work with module configurations.
 */
class ConfigurationHelper {

  /**
   * The module configuration.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected ImmutableConfig $configuration;

  /**
   * Construct.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configuration = $config_factory->get(SettingsForm::JSONAPI_LINKS_SETTINGS);
  }

  /**
   * Checks if links for the reference field are disabled.
   *
   * @return bool
   *   True if links are disabled and false otherwise.
   */
  public function isEntityRefenceFieldLinksDisabled() {
    return $this->configuration->get('remove_links_relationship') == 1;
  }

  /**
   * Checks if links for the entity are disabled.
   *
   * @return bool
   *   True if links are disabled and false otherwise.
   */
  public function isEntityLinksDisabled() {
    return $this->configuration->get('remove_links_entity') == 1;
  }

}
