<?php

namespace Drupal\jsonapi_links\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure JSON:API settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Configuration name.
   */
  const JSONAPI_LINKS_SETTINGS = 'jsonapi_links.settings';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'jsonapi_links_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      self::JSONAPI_LINKS_SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $field_type = NULL) {
    $config = $this->config('jsonapi_links.settings');

    $form['remove_links_relationship'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove all links attributes from entity referenced fields'),
      '#description' => $this->t('All links attributes  from entity referenced fields will be ignored.'),
      '#default_value' => $config->get('remove_links_relationship'),
    ];

    $form['remove_links_entity'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Remove all links attributes from entity'),
      '#description' => $this->t('All links attributes from entity will be ignored'),
      '#default_value' => $config->get('remove_links_entity'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config(self::JSONAPI_LINKS_SETTINGS);

    foreach ($form_state->getValues() as $key => $value) {
      if (strpos($key, 'remove_') !== 0) {
        continue;
      }
      $config->set($key, $value);
    }

    $config->save();
  }

}
