<?php

namespace Drupal\jsonapi_links;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;

/**
 * Replace the JSON API services.
 */
class JsonapiLinksServiceProvider extends ServiceProviderBase {

  /**
   * {@inheritdoc}
   */
  public function alter(ContainerBuilder $container) {
    $container_modules = $container->getParameter('container.modules');
    $jsonapi_impostor_path = dirname($container_modules['jsonapi_links']['pathname']) . '/src-impostor-normalizers';

    // Overrides original jsonapi normalize service.
    $container->getDefinition('serializer.normalizer.resource_object.jsonapi')
      ->setFile($jsonapi_impostor_path . '/ResourceObjectNormalizer.php')
      ->setClass('Drupal\jsonapi\Normalizer\ImpostorFrom\jsonapi_links\ResourceObjectNormalizer');

    // Overrides json api controller.
    if (isset($container_modules['jsonapi_defaults'])) {
      $container->getDefinition('jsonapi.entity_resource')
        ->setClass('Drupal\jsonapi_links\Controller\JsonApiExtrasEntityResource');
    }
    else {
      $container->getDefinition('jsonapi.entity_resource')
        ->setClass('Drupal\jsonapi_links\Controller\JsonApiEntityResource');
    }

    // Overrides json api access checker.
    $container->getDefinition('jsonapi.entity_access_checker')
      ->setClass('Drupal\jsonapi_links\Access\EntityAccessChecker');
  }

}
